@@ -1,4 +1,4 @@
-from django.conf.urls import url, include
+from django.urls import re_path, include
 from rest_framework.routers import DefaultRouter
 
 from task_api.views import TaskInfoViewSet
@@ -7,5 +7,5 @@ router = DefaultRouter()
 router.register(r'tasks', TaskInfoViewSet)
 
 urlpatterns = [
-    url(r'^', include(router.urls))
+    re_path(r'^', include(router.urls))
 ]
